package WebGUI::i18n::Dutch::Asset_EventManagementSystem;
use utf8;
our $I18N = {
  'Admin manage sub events large resultset' => {
    'lastUpdated' => '1148287015',
    'message' => 'De evenementen hieronder kunnen bewerkt worden. Gezien het grote aantal van sub-evenementen worden deze nu niet getoond. Specificeer uw keuze met behulp van de standaard of geavanceerde filter opties hierboven. '
  },
  'Admin manage sub events small resultset' => {
    'lastUpdated' => '1148287153',
    'message' => 'De evenementen hieronder kunnen bewerkt worden. De lijst met evenementen kan met behulp van de standaard of geavanceerde filter opties hierboven gespecificeerd worden.'
  },
  'Event Number' => {
    'lastUpdated' => '1148287171',
    'message' => 'Evenement nummer'
  },
  'None' => {
    'lastUpdated' => '1148287182',
    'message' => 'Geen'
  },
  'Pagination variables' => {
    'lastUpdated' => '1149853427',
    'message' => 'Standaard variabelen voor afbreken paginas'
  },
  'Unlink User' => {
    'lastUpdated' => '1148287423',
    'message' => 'Verwijder de link met deze gebruiker.'
  },
  'User sub events large resultset' => {
    'lastUpdated' => '1148287502',
    'message' => 'De volgende sub-evenementen kunnen ook gekozen worden. Gezien het grote aantal van sub-evenementen worden deze nu niet getoond. Specificeer uw keuze met behulp van de standaard of geavanceerde filter opties hierboven.'
  },
  'User sub events small resultset' => {
    'lastUpdated' => '1148287596',
    'message' => 'Er kan ook gekozen worden uit de volgende sub-evenementen. De lijst met sub-evenementen kan met behulp van de standaard of geavanceerde filter opties hierboven gespecificeerd worden.'
  },
  'add a badge' => {
    'lastUpdated' => '1213713987',
    'message' => 'Voeg een naamplaatje toe'
  },
  'add a badge group' => {
    'lastUpdated' => '1213714007',
    'message' => 'Voeg een naamplaatjes groep toe'
  },
  'add a ribbon' => {
    'lastUpdated' => '1215446840',
    'message' => 'Voeg een kortingsbon toe'
  },
  'add a ticket' => {
    'lastUpdated' => '1213702793',
    'message' => 'Voeg een kaartje toe'
  },
  'add a token' => {
    'lastUpdated' => '1215446898',
    'message' => 'Voeg een voucher toe'
  },
  'add an event meta field' => {
    'lastUpdated' => '1213702827',
    'message' => 'Voeg een metaveld toe aan een evenement'
  },
  'add discount pass' => {
    'lastUpdated' => '1148287618',
    'message' => 'Voeg kortingspas toe.'
  },
  'add more items' => {
    'lastUpdated' => '1213702804',
    'message' => 'Voeg meer objecten toe'
  },
  'add prerequisite set' => {
    'lastUpdated' => '1148287684',
    'message' => 'Voeg een set met vereisten toe.'
  },
  'add registrant' => {
    'lastUpdated' => '1148287850',
    'message' => 'Voeg een deelnemer toe.'
  },
  'add submission' => {
    'lastUpdated' => '1258535976',
    'message' => 'Nieuw'
  },
  'add to badge' => {
    'lastUpdated' => '1213714236',
    'message' => 'Voeg toe aan naamplaatje'
  },
  'add to badge message' => {
    'lastUpdated' => '1148288371',
    'message' => '%s is met succes toegevoegd aan je badge.'
  },
  'add to cart' => {
    'lastUpdated' => '1148287884',
    'message' => 'Voeg toe aan winkelwagen.'
  },
  'add/edit approve event' => {
    'lastUpdated' => '1148287905',
    'message' => 'Keur evenement goed.'
  },
  'add/edit event description' => {
    'lastUpdated' => '1148288397',
    'message' => 'Omschrijving'
  },
  'add/edit event description description' => {
    'lastUpdated' => '1148288449',
    'message' => 'Dit zijn de details over het evenement zoals plaats, tijd en wat het evenement inhoudt.'
  },
  'add/edit event end date' => {
    'lastUpdated' => '1213966366',
    'message' => 'Einde'
  },
  'add/edit event image' => {
    'lastUpdated' => '1148288960',
    'message' => 'Afbeelding bij evenement'
  },
  'add/edit event image description' => {
    'lastUpdated' => '1148289041',
    'message' => 'Een afbeelding die het evenement verduidelijkt voor de bezoekers.'
  },
  'add/edit event maximum attendees' => {
    'lastUpdated' => '1213966389',
    'message' => 'Beschrijving'
  },
  'add/edit event operator' => {
    'lastUpdated' => '1148289526',
    'message' => 'Bestuurder'
  },
  'add/edit event operator description' => {
    'lastUpdated' => '1208520992',
    'message' => 'Wanneer vereiste evenementen aan dit evenement gekoppeld zijn, kan er gespecificeerd worden of alle evenementen vereist zijn (en) of dat een willekeurig evenemenet vereist is (of).'
  },
  'add/edit event price description' => {
    'lastUpdated' => '1208521149',
    'message' => 'De deelnemersbijdrage voor dit evenement.'
  },
  'add/edit event required events' => {
    'lastUpdated' => '1148289701',
    'message' => 'vereiste evenementen'
  },
  'add/edit event required events description' => {
    'lastUpdated' => '1148289791',
    'message' => 'Het kan vereist worden dat een gebruiker geregistreerd moet zijn voor bepaalde evenementen, voordat deze zich in kan schrijven voor dit evenement.'
  },
  'add/edit event start date' => {
    'lastUpdated' => '1213966377',
    'message' => 'Begin'
  },
  'add/edit event start date help' => {
    'lastUpdated' => '1213966412',
    'message' => 'De tijd en datum waarop het evenement begint.'
  },
  'add/edit event template' => {
    'lastUpdated' => '1213966486',
    'message' => 'Evenement beheer systeem evenementensjabloon'
  },
  'add/edit event title' => {
    'lastUpdated' => '1148289961',
    'message' => 'Titel van het evenement'
  },
  'add/edit event title description' => {
    'lastUpdated' => '1148289982',
    'message' => 'Voer de naam of titel van het evenement in.'
  },
  'add/edit useSalesTax' => {
    'lastUpdated' => '1166194084',
    'message' => 'BTW gebruiken?'
  },
  'add/edit useSalesTax description' => {
    'lastUpdated' => '1166194105',
    'message' => 'Moet er BTW aan dit evenement worden toegevoegd?'
  },
  'addBadgeUrl' => {
    'lastUpdated' => '1216646076',
    'message' => 'URL om een naamplaatje aan het systeem toe te voegen.'
  },
  'addEvent.label' => {
    'lastUpdated' => '1166194134',
    'message' => 'De standaard tekst van de link voor het toevoegen van evenementen.'
  },
  'addEvent.url' => {
    'lastUpdated' => '1149861846',
    'message' => '<p>Een URL die de gebruiker meeneemt naar een scherm waar een nieuw evenement kan worden toegevoegd. </p>'
  },
  'addRibbonUrl' => {
    'lastUpdated' => '1216646121',
    'message' => 'URL om een kortingspas aan het systeem toe te voegen.<br /> '
  },
  'addTicketUrl' => {
    'lastUpdated' => '1216646140',
    'message' => 'URL om een kaartje aan een naamplaatje toe te voegen.<br /> '
  },
  'addToBadgeMessage' => {
    'lastUpdated' => '1207906900',
    'message' => '<p>Een bericht van het systeem waarin wordt vermeld of de badge met succes is toegevoegd aan deze transactie. </p>'
  },
  'addTokenUrl' => {
    'lastUpdated' => '1216649068',
    'message' => 'Het URL voor het toevoegen van een voucher aan een naamplaatje.'
  },
  'address' => {
    'lastUpdated' => '1148290710',
    'message' => 'Adres'
  },
  'address1' => {
    'lastUpdated' => '1216648062',
    'message' => 'Regel 1 van het adres van de houder van het naamplaatje.'
  },
  'address2' => {
    'lastUpdated' => '1216648071',
    'message' => 'Regel 2 van het adres van de houder van het naamplaatje.<br /> '
  },
  'address3' => {
    'lastUpdated' => '1216648079',
    'message' => 'Regel 3 van het adres van de houder van het naamplaatje.<br /> '
  },
  'addressBook' => {
    'lastUpdated' => '1221207049',
    'message' => 'Een knop weermee een adres uit het adresboek van de gebruiker opgehaald kan worden.'
  },
  'advSearch.formHeader' => {
    'lastUpdated' => '1149861271',
    'message' => '<p>Koptekst voor een geavanceerde zoekopdracht. </p>'
  },
  'all' => {
    'lastUpdated' => '1148290721',
    'message' => 'Alles'
  },
  'allowed sub events' => {
    'lastUpdated' => '1148290975',
    'message' => 'Gezien de evenementen in de winkelwagen kan er ook meegedaan worden aan de volgende sub-evenementen. '
  },
  'amount off' => {
    'lastUpdated' => '1148291413',
    'message' => 'Zet hoeveelheden uit.'
  },
  'any' => {
    'lastUpdated' => '1148291542',
    'message' => 'Elke'
  },
  'appUrl' => {
    'lastUpdated' => '1149862411',
    'message' => 'Een URL terug naar het hoofdscherm van de asset. '
  },
  'approved' => {
    'lastUpdated' => '1258535984',
    'message' => 'Goedgekeurd'
  },
  'assetId' => {
    'lastUpdated' => '1257329195',
    'message' => 'AssetId van het ticket.'
  },
  'assetName' => {
    'lastUpdated' => '1213702842',
    'message' => 'Evenementen beheer'
  },
  'assetSize' => {
    'lastUpdated' => '1257329210',
    'message' => 'De grootte van dit ticket asset'
  },
  'assigned discount pass' => {
    'lastUpdated' => '1148291814',
    'message' => 'Toegekende kortingspas'
  },
  'assigned discount pass description' => {
    'lastUpdated' => '1148291873',
    'message' => 'De kortingspas, als die er is, die van toepassing is op dit evenement.'
  },
  'assigned prerequisite set' => {
    'lastUpdated' => '1148291896',
    'message' => 'Toegekende set van vereisten'
  },
  'assigned prerequisite set description' => {
    'lastUpdated' => '1207829640',
    'message' => 'De set van vereisten voor dit evenement voordat dit aan een badge kan worden toegevoegd.'
  },
  'associated user' => {
    'lastUpdated' => '1148292356',
    'message' => 'Gekoppelde gebruiker'
  },
  'associated user description' => {
    'lastUpdated' => '1166194140',
    'message' => 'Een deelnemer kan aan een gebruiker uit de WebGUI gebruikers database gekoppeld worden en de informatie van de deelnemer synchroniseren met hun WebGUI profiel. Ook kan met de informatie van de deelnemer een nieuwe WebGUI gebruiker aangemaakt worden, waarbij de ingevulde informatie verwerkt wordt in het profiel.'
  },
  'badge builder template' => {
    'lastUpdated' => '1213966512',
    'message' => 'Naamplaatjes generator sjabloon'
  },
  'badge builder template help' => {
    'lastUpdated' => '1214557608',
    'message' => 'Welk sjabloon moet gebruikt worden voor het naamplaatjes generator scherm?'
  },
  'badge group name' => {
    'lastUpdated' => '1214557619',
    'message' => 'Naamplaatjes groeps naam'
  },
  'badge group name help' => {
    'lastUpdated' => '1214558397',
    'message' => 'Voer een naam in waarmee naamplaatjes aan de verkochte kaartjes gelinkt kunnen worden.'
  },
  'badge group ticketsPerBadge' => {
    'lastUpdated' => '1311779967',
    'message' => 'Tickets per naamplaatje'
  },
  'badge group ticketsPerBadge help' => {
    'lastUpdated' => '1311780002',
    'message' => 'Het aantal tickets dat voor elk naamplaatje in deze groep verkoocht kan worden.'
  },
  'badge groups' => {
    'lastUpdated' => '1214558409',
    'message' => 'Naamplaatjes groepen'
  },
  'badge holder information' => {
    'lastUpdated' => '1214558420',
    'message' => 'Naamplaatjes houder informatie'
  },
  'badge id' => {
    'lastUpdated' => '1148295164',
    'message' => 'badgeId'
  },
  'badge instructions' => {
    'lastUpdated' => '1214558434',
    'message' => 'Naamplaatje instructies'
  },
  'badge instructions help' => {
    'lastUpdated' => '1214558467',
    'message' => 'Geef de gebruiker wat hulp voor het gebruik van een naamplaatje.'
  },
  'badge number' => {
    'lastUpdated' => '1214558479',
    'message' => 'Naamplaatje #'
  },
  'badgeAssetId' => {
    'lastUpdated' => '1216648111',
    'message' => 'Het asset ID van dit naamplaatje.'
  },
  'badgeBuilderTemplateId help' => {
    'lastUpdated' => '1216648234',
    'message' => 'Het ID van het sjabloon voor het scherm waar naamplaatjes gemaakt worden.'
  },
  'badgeId' => {
    'lastUpdated' => '1216648257',
    'message' => 'Het ID van het naamplaatje van de huidige gebruiker.'
  },
  'badgeInstructions help' => {
    'lastUpdated' => '1216648275',
    'message' => 'Instructies voor de gebruiker over het naamplaatje.'
  },
  'badgeLabel' => {
    'lastUpdated' => '1216648374',
    'message' => 'Een persoonlijk label dat samen met het naamplaatje in de winkelwagen van de gebruiker gestopt wordt.'
  },
  'badgeNumber' => {
    'lastUpdated' => '1216648385',
    'message' => 'Het nummer van dit naamplaatje.'
  },
  'badgeTitle' => {
    'lastUpdated' => '1216648405',
    'message' => 'De titel van het naamplaatje dat afgedrukt gaat worden.'
  },
  'badgeUrl' => {
    'lastUpdated' => '1216986284',
    'message' => 'Het URL voor het toevoegen van nog een naamplaatje aan de winkelwagen van de gebruiker.'
  },
  'basicSearch.formHeader' => {
    'lastUpdated' => '1149861249',
    'message' => '<p>Koptekst voor een standaard zoekopdracht. </p>'
  },
  'buildBadgeUrl' => {
    'lastUpdated' => '1216648661',
    'message' => 'URL waar informatie over het huidige naamplaatje getoond wordt.'
  },
  'buy' => {
    'lastUpdated' => '1213702851',
    'message' => 'Kopen'
  },
  'buy badge' => {
    'lastUpdated' => '1220532374',
    'message' => 'Koop een naamplaatje'
  },
  'buyBadgeUrl' => {
    'lastUpdated' => '1216648138',
    'message' => 'Het URL waar een naamplaatje gekocht kan worden.'
  },
  'calendarJS' => {
    'lastUpdated' => '1149861228',
    'message' => '<p>Script tag waarmee de javascript kalender ingesteld kan worden. </p>'
  },
  'canAddEvents' => {
    'lastUpdated' => '1150098264',
    'message' => 'Een functie die aangeeft of de huidige gebruiker evenementen toe kan voegen. Beheerders, de eigenaar van de transactie, de gebruiker die de registratie heeft gedaan of de gebruiker waar de registratie voor is gedaan kunnen evenementen toevoegen. '
  },
  'canEdit' => {
    'lastUpdated' => '1216646179',
    'message' => 'Een functie die aangeeft of de huidige gebruiker het evenementenbeheersysteem kan bewerken.'
  },
  'canManageEvents' => {
    'lastUpdated' => '1149861897',
    'message' => '<p>Een teken dat de huidige gebruiker in de groep zit die evenementen mag beheren. </p>'
  },
  'canReturn' => {
    'lastUpdated' => '1149862543',
    'message' => 'Een functie die aangeeft of de huidige gebruiker evenementen terug mag sturen gedurende de aankoop. Gebruikers die evenementen kunnen toevoegen zitten in deze groep.'
  },
  'canReturnItinerary' => {
    'lastUpdated' => '1149862574',
    'message' => 'Een functie die aangeeft of dit evenement teruggestuurd kan worden.'
  },
  'canReturnTransaction' => {
    'lastUpdated' => '1149862610',
    'message' => 'Een functie die klopt als elke aankoop teruggestuurd kan worden.'
  },
  'cancel registration' => {
    'lastUpdated' => '1166194153',
    'message' => 'Registratie annuleren'
  },
  'check required fields' => {
    'lastUpdated' => '1190027331',
    'message' => 'Deze verplichte velden werden niet meegestuurd:'
  },
  'checked in' => {
    'lastUpdated' => '1214558571',
    'message' => 'Ingechecked'
  },
  'checkout' => {
    'lastUpdated' => '1148295345',
    'message' => 'Uitschrijven'
  },
  'checkout template help title' => {
    'lastUpdated' => '1189348422',
    'message' => 'EMS checkout template'
  },
  'checkout.label' => {
    'lastUpdated' => '1149862981',
    'message' => 'Een label dat bij checkout.url hoort, dit is het woord checkout.'
  },
  'checkout.url' => {
    'lastUpdated' => '1166194438',
    'message' => 'De URL voor het weergeven van de winkelwagen van de gebruiker.'
  },
  'choose a file to import' => {
    'lastUpdated' => '1190027343',
    'message' => 'Kies een bestand om te importeren'
  },
  'city' => {
    'lastUpdated' => '1148295432',
    'message' => 'Stad'
  },
  'clear form' => {
    'lastUpdated' => '1314787613',
    'message' => 'Formulier leegmaken'
  },
  'confirm delete event metadata' => {
    'lastUpdated' => '1213710657',
    'message' => 'Weet u zeker dat dit metadata veld verwijderd moet worden? De metadata waarden van dit veld worden verwijderd uit alle evenementen.'
  },
  'confirm delete prerequisite set' => {
    'lastUpdated' => '1148295702',
    'message' => 'Weet u zeker dat deze set van vereisten verwijderd moet worden? De links met alle evenementen die deze set van vereisten gebruiken zullen ook verwijderd worden.'
  },
  'confirm delete purchase' => {
    'lastUpdated' => '1148295773',
    'message' => 'Weet u zeker dat u dit object uit de winkelwagen wilt verwijderen? Alle veranderingen die gemaakt zijn aan de huidige badge die bewerkt wordt zullen ook verloren gaan.'
  },
  'continue' => {
    'lastUpdated' => '1148295929',
    'message' => 'Ga verder'
  },
  'continue.label' => {
    'lastUpdated' => '1149861996',
    'message' => '<p>Een label &quot;Ga verder&quot;, dat bij continue.url hoort. </p>'
  },
  'continue.url' => {
    'lastUpdated' => '1149861975',
    'message' => '<p>Een URL waarmee dit evenement aan de winkelwagen kan worden toegevoegd. </p>'
  },
  'country' => {
    'lastUpdated' => '1148295938',
    'message' => 'Land'
  },
  'create a badge for myself' => {
    'lastUpdated' => '1148295967',
    'message' => 'Maak een badge aan voor mijzelf.'
  },
  'create a badge for someone else' => {
    'lastUpdated' => '1148295984',
    'message' => 'Maak een badge aan voor iemand anders.'
  },
  'create new user' => {
    'lastUpdated' => '1208521228',
    'message' => 'Maak nieuwe gebruiker aan.'
  },
  'created' => {
    'lastUpdated' => '1258535993',
    'message' => 'Aangemaakt'
  },
  'created by' => {
    'lastUpdated' => '1148296028',
    'message' => 'Aangemaakt door'
  },
  'created by description' => {
    'lastUpdated' => '1208521272',
    'message' => 'De gebruiker die de identiteit van deze deelnemer heeft aangemaakt.'
  },
  'createdByUserId' => {
    'lastUpdated' => '1149862637',
    'message' => 'De identificatie van de gebruiker die deze badge heeft gemaakt.'
  },
  'creationDate' => {
    'lastUpdated' => '1257329235',
    'message' => 'Epoch waarde van de datum waarop het asset is gemaakt.'
  },
  'customRequestUrl' => {
    'lastUpdated' => '1216648180',
    'message' => 'Een URL voor de YUI voor het opzoeken van informatie over het huidige naamplaatje.'
  },
  'datePurchasedHuman' => {
    'lastUpdated' => '1149860995',
    'message' => '<div class="&quot;helpIndent&quot;"><p>De datum en tijd waarop deze aankoop is begonnen in een door mensen te lezen formaat.</p>  </div>'
  },
  'default badge instructions' => {
    'lastUpdated' => '1214560389',
    'message' => 'Er is een naamplaatje nodig om deze bijeenklomst te bezoeken. Kies een naamplaatje dat voldoet aan de eisen en budget.'
  },
  'default ribbon instructions' => {
    'lastUpdated' => '1215444045',
    'message' => 'Kortingspassen geven korting op een groep van gerelateerde evenementen. Er kunnen &eacute;&eacute;n of meer kortingspassen aan het naamplaatje worden toegevoegd voor kortingen op gerelateerde evenementen.'
  },
  'default submitted location list' => {
    'lastUpdated' => '1258549658',
    'message' => 'Dit is de standaard lijst met locaties voor het invoeren van een evenement.'
  },
  'default ticket instructions' => {
    'lastUpdated' => '1214560967',
    'message' => 'Met kaarten kunnen stoelen gereserveerd worden bij bijeenkomsten. Voeg kaarten toe aan het naamplaatje voor evenementen die u wilt bezoeken.'
  },
  'default token instructions' => {
    'lastUpdated' => '1216649130',
    'message' => 'Vouchers zijn valuta voor een conferentie. Er kunnen evenementen en andere objecten mee aangeschaft worden zonder een speciaal kaartje ervoor te hoeven kopen.'
  },
  'defines discount pass' => {
    'lastUpdated' => '1208521338',
    'message' => '<p><strong>Dit evenement heeft een bijbehorende kortingspas</strong>.</p><p>Wanneer de gebruiker dit evenement toevoegt aan zijn/haar winkelwagen, wordt (bij uitschrijven) de bijbehorende korting van kracht op elk evenement dat deel uit maakt van deze kortingspas.&nbsp;</p>'
  },
  'delete' => {
    'lastUpdated' => '1213702859',
    'message' => 'Verwijderen'
  },
  'denied' => {
    'lastUpdated' => '1258536001',
    'message' => 'Afgekeurd'
  },
  'description' => {
    'lastUpdated' => '1149859800',
    'message' => '<p>De omschrijving van dit evenement. </p>'
  },
  'discount amount' => {
    'lastUpdated' => '1148296415',
    'message' => 'De hoeveelheid korting'
  },
  'discount amount description' => {
    'lastUpdated' => '1148296656',
    'message' => 'Bij het veld voor de hoeveelheid kunnen verschillende eenheden worden ingevoerd voor de kortingspas. Voor procenten kan de instelling &quot;Percentage&quot; gekozen worden (voer 10 in voor 10% korting). De instelling &quot;Nieuwe prijs&quot; en &quot;Hoeveelheid korting&quot; zijn in absolute hoeveelheden valuta. De standaard waarde is &quot;0.00&quot;. '
  },
  'discount pass id' => {
    'lastUpdated' => '1148296671',
    'message' => 'Kortingspas ID'
  },
  'discount pass id description' => {
    'lastUpdated' => '1208521380',
    'message' => 'Er wordt intern een unieke identificatiecode gebruikt voor deze kortingspas. Bij het aanmaken van een nieuwe pas, zal dit het woord &quot;Nieuw&quot; zijn. '
  },
  'discount pass member' => {
    'lastUpdated' => '1148894288',
    'message' => '<p><strong>Dit evenement heeft een bijbehorende kortingspas.</strong></p><p>De geselecteerde hoeveelheid korting zal toegekend worden als ze allebei in de winkelwagen van deze gebruiker zitten.&nbsp;</p>'
  },
  'discount pass type' => {
    'lastUpdated' => '1148297045',
    'message' => 'Type kortingspas'
  },
  'discount pass type description' => {
    'lastUpdated' => '1148298325',
    'message' => 'Vul hier in of dit evenement een kortingspas gebruikt en zo ja, of een enkele is of een die gebruikt wordt door een groep.Er kan bijvoorbeeld een kortingspa, genaamd &quot;Bezoek alle sessies&quot; aangemaakt worden. Elke sessie zou vijfentwintig euro kosten, maar wel verband gelegd worden met de kortingspas. Als dan het &quot;Bezoek alle sessies&quot; evenement wordt aangeschaft, zal de korting worden afgetrokken.  '
  },
  'duration' => {
    'lastUpdated' => '1213702869',
    'message' => 'Duur'
  },
  'duration help' => {
    'lastUpdated' => '1213702883',
    'message' => 'Hoe lang duurt dit evenement?'
  },
  'early bird price' => {
    'lastUpdated' => '1222939062',
    'message' => 'Vroege vogel prijs'
  },
  'early bird price end date' => {
    'lastUpdated' => '1222939084',
    'message' => 'Einddatum vroege vogel prijs'
  },
  'early bird price end date help' => {
    'lastUpdated' => '1222939118',
    'message' => 'De datum waarop de vroege vogel prijs wordt vervangen door de volledige prijs.'
  },
  'early bird price help' => {
    'lastUpdated' => '1222939152',
    'message' => 'De speciale prijs van dit naamplaatje, wanneer de gebruiker zich vroeg inschrijft.'
  },
  'edit' => {
    'lastUpdated' => '1213703076',
    'message' => 'Bewerken'
  },
  'edit discount pass' => {
    'lastUpdated' => '1148298400',
    'message' => 'Bewerk kortingspas'
  },
  'edit prerequisite set' => {
    'lastUpdated' => '1148298505',
    'message' => 'Bewerk set van vereisten'
  },
  'edit registrant' => {
    'lastUpdated' => '1148299268',
    'message' => 'Bewerk deelnemer'
  },
  'edit submission form' => {
    'lastUpdated' => '1258549703',
    'message' => '"Bewerk inschrijving" sjabloon'
  },
  'email' => {
    'lastUpdated' => '1216645299',
    'message' => 'Het e-mail adres van de naamplaatje houder'
  },
  'email address' => {
    'lastUpdated' => '1148299310',
    'message' => 'Email adres'
  },
  'ems asset template variables' => {
    'lastUpdated' => '1216648702',
    'message' => 'Evenementenbeheersysteem sjabloon variabelen'
  },
  'ems badge' => {
    'lastUpdated' => '1215443937',
    'message' => 'Evenement beheer naamplaatje'
  },
  'ems ribbon' => {
    'lastUpdated' => '1215443951',
    'message' => 'Evenement beheer kortingspas'
  },
  'ems ticket' => {
    'lastUpdated' => '1215443963',
    'message' => 'Evenement beheer kaartje'
  },
  'ems token' => {
    'lastUpdated' => '1216649145',
    'message' => 'Evenementenbeheer voucher'
  },
  'ems view badge address1' => {
    'lastUpdated' => '1221207113',
    'message' => 'Formulier voor het eerste veld voor adressen in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.'
  },
  'ems view badge address2' => {
    'lastUpdated' => '1221207125',
    'message' => 'Formulier voor het tweede veld voor adressen in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br /> '
  },
  'ems view badge address3' => {
    'lastUpdated' => '1221207137',
    'message' => 'Formulier voor het derde veld voor adressen in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br /> '
  },
  'ems view badge city' => {
    'lastUpdated' => '1221207194',
    'message' => 'Formulierveld voor stad in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br /> '
  },
  'ems view badge country' => {
    'lastUpdated' => '1221207206',
    'message' => 'Formulierveld voor land in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />  '
  },
  'ems view badge description' => {
    'lastUpdated' => '1221207231',
    'message' => 'De beschrijving van het evenementenbeheersysteem naamplaatje.'
  },
  'ems view badge email' => {
    'lastUpdated' => '1221207243',
    'message' => 'Formulierveld voor e-mail in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />  '
  },
  'ems view badge error' => {
    'lastUpdated' => '1221207299',
    'message' => 'Fouten die kunnen optreden tijdens het proberen toe te voegen van dit naamplaatje aan de winkelwagen van de gebruiker.'
  },
  'ems view badge name' => {
    'lastUpdated' => '1221207317',
    'message' => 'Formulierveld voor de naam van de gebruiker in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />  '
  },
  'ems view badge organization' => {
    'lastUpdated' => '1221207335',
    'message' => 'Formulierveld voor orgaisatie van de gebruiker in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />  '
  },
  'ems view badge phone' => {
    'lastUpdated' => '1221207354',
    'message' => 'Formulierveld voor het telefoonnummer in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />  '
  },
  'ems view badge state' => {
    'lastUpdated' => '1221207367',
    'message' => 'Formulierveld voor staat/provincie in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />  '
  },
  'ems view badge submitAddress' => {
    'lastUpdated' => '1221207386',
    'message' => 'Knop waarmee de informatie ingezonden wordt.'
  },
  'ems view badge title' => {
    'lastUpdated' => '1221207411',
    'message' => 'De titel van het evenementenbeheersysteem naamplaatje'
  },
  'ems view badge zipcode' => {
    'lastUpdated' => '1221207424',
    'message' => 'Formulierveld voor de postcode in het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />  '
  },
  'ems.wobject.dir' => {
    'lastUpdated' => '1149862206',
    'message' => '<p>De URL van het evenementen beheersysteem in de WebGUI extras map.&nbsp;</p>'
  },
  'emsAssetId' => {
    'lastUpdated' => '1216646232',
    'message' => 'De asset id van het evenementenbeheersysteem waaronder dit naamplaatje valt.'
  },
  'encryptPage' => {
    'lastUpdated' => '1257329279',
    'message' => 'Of de pagina waar het ticket getoond wordt wel of niet ge&euml;ncrypt moet worden.'
  },
  'endDate' => {
    'lastUpdated' => '1149861524',
    'message' => '<div class="&quot;helpIndent&quot;"><p>De datum en tijd waarop dit evenement afloopt, in epoch formaat. </p></div>'
  },
  'endDate.human' => {
    'lastUpdated' => '1149860551',
    'message' => '<p>De einddatum-en tijd van dit evenement, in een door mensen te lezen formaat.</p>'
  },
  'endDateHuman' => {
    'lastUpdated' => '1149860583',
    'message' => 'De einddatum-en tijd van dit evenement, in een epoch formaat.'
  },
  'ends' => {
    'lastUpdated' => '1148299333',
    'message' => 'Eindigt'
  },
  'ends.label' => {
    'lastUpdated' => '1149862072',
    'message' => '<p>Het label &quot;Eindigt&quot;. </p>'
  },
  'enter import file' => {
    'lastUpdated' => '1190027379',
    'message' => 'Geef een bestand om te importeren op.'
  },
  'error' => {
    'lastUpdated' => '1148299352',
    'message' => 'Fout:'
  },
  'error badge group ticket limit' => {
    'lastUpdated' => '1311780051',
    'message' => 'Maximum aantal tickets bereikt voor dit naamplaatje. Kan %s niet toevoegen.'
  },
  'error no colon' => {
    'lastUpdated' => '1190027389',
    'message' => 'Fout'
  },
  'event number' => {
    'lastUpdated' => '1215443875',
    'message' => 'Evenement #'
  },
  'event number help' => {
    'lastUpdated' => '1215443923',
    'message' => 'Een nummer als representatie van het evenement, zodat er makkelijk naar verwezen kan worden in bijvoorbeeld een catalogus.'
  },
  'event start date' => {
    'lastUpdated' => '1216648195',
    'message' => 'Begindatum'
  },
  'event submission main template' => {
    'lastUpdated' => '1258550119',
    'message' => 'Evenement toevoegen sjabloon'
  },
  'event submission main template help' => {
    'lastUpdated' => '1258550227',
    'message' => 'Dit sjabloon wordt gebruikt voor het tonen van de hoofdpagina van de module waarmee evenementen worden toegevoegd. Het heeft een dynamische tabset waarmee verschillende onderdel van de interface voor het toevoegen mee getoond worden.'
  },
  'event submission queue template' => {
    'lastUpdated' => '1258550271',
    'message' => 'Evenement toevoegen wachtrij sjabloon'
  },
  'event submission queue template help' => {
    'lastUpdated' => '1258550340',
    'message' => 'Dit is het sjabloon waarmee de Wachtrij voor toegevoegde evenementen getoond worden, dit wordt gebruikt voor de mensen die evenementen toevoegen en beheerders.'
  },
  'event submission template' => {
    'lastUpdated' => '1258550352',
    'message' => 'Evenement toevoegn sjabloon'
  },
  'event submission template help' => {
    'lastUpdated' => '1258551097',
    'message' => 'Dit sjabloon wordt gebruikt voor het toevoegen van evenementen. De meeste inhoud wordt samengesteld uit het formulier gebaseerd op de beschrijving van de beheerder.'
  },
  'event template help title' => {
    'lastUpdated' => '1148302925',
    'message' => ' Evenementen sjabloon voor het evenementen beheersysteem'
  },
  'eventIsApproved' => {
    'lastUpdated' => '1208521441',
    'message' => '<p>Een indicator die waar is als het evenement is goedgekeurd. </p>'
  },
  'eventIsFull' => {
    'lastUpdated' => '1166194498',
    'message' => 'Een indicator die waar is als er geen plaatsen voor het evenement over zijn.'
  },
  'eventMetaData' => {
    'lastUpdated' => '1257329300',
    'message' => 'Meta data van het evenement in een JSON data structuur.'
  },
  'events required by description' => {
    'lastUpdated' => '1148302981',
    'message' => 'Vink de evenementen aan die onderdeel uitmaken van deze vereisten-set.'
  },
  'events required by this prerequisite set' => {
    'lastUpdated' => '1148303012',
    'message' => 'Vereiste evenementen by deze set van vereisten.'
  },
  'events_loop' => {
    'lastUpdated' => '1149861413',
    'message' => 'Deze kring bevat alle goedgekeurde evenementen, zodanig dat gebruikers zich in kunnen schrijven.'
  },
  'expire ems cart items' => {
    'lastUpdated' => '1216648825',
    'message' => 'Verlopen van evenementen in winkelwagen.'
  },
  'export' => {
    'lastUpdated' => '1213703095',
    'message' => 'Exporteren'
  },
  'export error' => {
    'lastUpdated' => '1190027361',
    'message' => 'Er is een fout opgetreden in de exportprocedure'
  },
  'export events' => {
    'lastUpdated' => '1190027401',
    'message' => 'Exporteer events'
  },
  'exportTicketsUrl' => {
    'lastUpdated' => '1216648885',
    'message' => 'Het URL waar kaartjes ge&euml;xporteerd worden. Momenteel is dit nog niet ge&iuml;mplementeerd.'
  },
  'extraHeadTags' => {
    'lastUpdated' => '1257329341',
    'message' => 'Extra eigenschappen die in de header van dit ticket getoond moet worden.'
  },
  'extraHeadTagsPacked' => {
    'lastUpdated' => '1257759275',
    'message' => 'Extra eigenschappen die zonder spaties in de header van het ticket getoond worden.'
  },
  'failed' => {
    'lastUpdated' => '1258549444',
    'message' => 'Mislukt'
  },
  'feedback' => {
    'lastUpdated' => '1258549452',
    'message' => 'Wacht op reactie'
  },
  'field count mismatch' => {
    'lastUpdated' => '1190027426',
    'message' => 'Record %d heeft %d velden, niet %d zoals aangegeven door de checkboxes.'
  },
  'filter' => {
    'lastUpdated' => '1148303031',
    'message' => 'Filteren'
  },
  'first name' => {
    'lastUpdated' => '1148303048',
    'message' => 'Voornaam'
  },
  'forced narrowing' => {
    'lastUpdated' => '1148303195',
    'message' => 'Wegens het grote aantal beschikbare vereisten, worden er nu geen afgebeeld. Specificeer uw zoekopdracht met de standaard of geavanceerde filteropties hierboven, zodat het aantal resultaten beperkt wordt.'
  },
  'formFooter' => {
    'lastUpdated' => '1221207491',
    'message' => 'De onderkant van het formulier voor het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />  '
  },
  'formHeader' => {
    'lastUpdated' => '1221207504',
    'message' => 'De bovenkant van het formulier voor het evenementenbeheersysteem sjabloon voor het bekijken van naamplaatjes.<br />   '
  },
  'getBadgesUrl' => {
    'lastUpdated' => '1216648930',
    'message' => 'URL voor het leveren van informatie over het naamplaatje in JSON formaat voor de YUI database.'
  },
  'getRegistrantsUrl' => {
    'lastUpdated' => '1216648954',
    'message' => 'URL voor het leveren van informatie over de registrant in JSON formaat.<br /> '
  },
  'getRibbonsUrl' => {
    'lastUpdated' => '1216649017',
    'message' => 'URL voor het leveren van informatie over de kortingspas in JSON formaat.<br /> '
  },
  'getTicketsUrl' => {
    'lastUpdated' => '1216649028',
    'message' => 'URL voor het leveren van informatie over kaartjes in JSON formaat.<br />  '
  },
  'getTokensUrl' => {
    'lastUpdated' => '1216649177',
    'message' => 'Het URL voor het verkrijgen van informatie over een voucher in JSON formaat.'
  },
  'groupIdEdit' => {
    'lastUpdated' => '1257329477',
    'message' => 'De id van de groep die dit ticket kan bewerken.'
  },
  'groupIdView' => {
    'lastUpdated' => '1257329494',
    'message' => 'De id van de groep die dit ticket kan bekijken.'
  },
  'hasBadge' => {
    'lastUpdated' => '1216646310',
    'message' => 'Een functie die aangeeft of de huidige gebruiker een naamplaatje heeft.'
  },
  'hasCheckedIn' => {
    'lastUpdated' => '1216646300',
    'message' => 'Een functie die war is als de gebruiker ingechecked is bij het evenement.'
  },
  'help badgeMeta' => {
    'lastUpdated' => '1311780116',
    'message' => 'Voeg een metadata waarde toe aan het sjabloon door de naam toe te voegen aan "badgeMeta_". Voorbeeld: badgeMeta_department'
  },
  'help ticketMeta' => {
    'lastUpdated' => '1311780140',
    'message' => 'Voeg een metadata waarde toe aan het sjabloon door de naam toe te voegen aan "ticketMeta_". Voorbeeld: ticketMeta_department'
  },
  'hours' => {
    'lastUpdated' => '1213703163',
    'message' => 'Uren'
  },
  'ignore first line' => {
    'lastUpdated' => '1190027452',
    'message' => 'Negeer de eerste regel?'
  },
  'image' => {
    'lastUpdated' => '1149859834',
    'message' => '<p>De afbeelding die gekozen is bij dit evenement. </p>'
  },
  'import' => {
    'lastUpdated' => '1213703155',
    'message' => 'Importeren'
  },
  'import blank line' => {
    'lastUpdated' => '1190027443',
    'message' => 'Record %d was leeg (overgeslagen).'
  },
  'import events' => {
    'lastUpdated' => '1190027313',
    'message' => 'Importeer events'
  },
  'import field is duplicate key description' => {
    'lastUpdated' => '1208521638',
    'message' => 'Om goed met dubbelingen om te gaan, moet het systeem in staat zijn dubbelingen te herkennen. Door deze checkboxen aan te vinken, weet het systeem welk veld moet worden bekeken om te zien of het een dubbeling betreft. '
  },
  'import field is duplicate key title' => {
    'lastUpdated' => '1190027196',
    'message' => 'Veld is een dubbele sleutel'
  },
  'import file contains field description' => {
    'lastUpdated' => '1190027186',
    'message' => 'Vink de checkboxes naast de velden aan welke moeten worden opgenomen in het te importeren bestand. De velden moeten in de aangegeven volgorde staan en alle verplichte velden moeten aangevinkt zijn en ingevuld om het importeren goed te laten gaan.'
  },
  'import file contains field title' => {
    'lastUpdated' => '1190027115',
    'message' => 'Bestand bevat veld'
  },
  'import form header' => {
    'lastUpdated' => '1190027103',
    'message' => 'Met gebruik van dit formulier kun je data importeren, direct in dit EMS. Wees er zeker van dat velden zijn gespecificeerd in de volgorde zoals beneden weergegeven.'
  },
  'import hoverhelp dups' => {
    'lastUpdated' => '1190027058',
    'message' => 'Het systeem zal gebruiken wat er wordt opgegeven onder "Veld is dubbele sleutel" als het veld om vast te stellen of er dubbelingen zijn gevonden. Wanneer een dubbeling is gevonden, bepaalt dit keuzeveld wat er met de dubbeling gebeurt. Dit is hetzij het overslaan van het inkomende record, hetzij het overschrijven van het oude record. Alle velden in overschreven records worden overschreven, onafhankelijk van de vraag of ze aanwezig zijn in het inkomende record of niet. '
  },
  'import hoverhelp file' => {
    'lastUpdated' => '1190026817',
    'message' => 'Upload een komma-gescheiden bestand (CSV) om gebeurtenissen te importeren. (Rekenbladen, zoals Excel, kunnen bestanden bewaren als CSV bestand.) De velden moeten komma-gescheiden zijn, met dubbele aanhalingstekens ("") om de veldwaarden die komma\'s bevatten. Dubbele aanhalingstekens binnen de waarde worden geescaped met een ander dubbel aanhalingsteken (""). Het bestand wordt gecontroleerd op het aantal velden en verplichte velden voor er iets wordt geimporteerd. Als er fouten worden gevonden, dan wordt dat gemeld en wordt er niets geimporteerd. Tot de controle behoort niet of LDAP, externe databases, of templates geldig zijn. Het formaat van speciale velden is zoals het is voor export. Bij vragen over hoe een veld moet worden geformatteerd om geimporteerd te worden, kijk dan naar hoe het wordt geexporteerd. Velden met lijsten met meerdere waardes moeten worden samengevoegd in hetzelfde CSV veld gescheiden met een punt-komma (;). '
  },
  'import hoverhelp first line' => {
    'lastUpdated' => '1190026489',
    'message' => 'Als de eerste regel van het te importeren bestand veldnamen bevat in plaats van records klik hier \'ja\' anders \'nee\'.'
  },
  'import invalid prereq' => {
    'lastUpdated' => '1208521754',
    'message' => 'Record %d heeft een ongeldige Prerequisite Set Name value (%s). De bijbehorende Prerequisite Set moet aangemaakt worden voor de import.'
  },
  'import invalid status' => {
    'lastUpdated' => '1208521764',
    'message' => 'Record %d heeft een ongeldige Status (%s). Geldige waarden zijn: Goedgekeurd, Afgebroken, Geweigerd, Wachtend. '
  },
  'import invalid template' => {
    'lastUpdated' => '1208521776',
    'message' => 'Record %d heeft een ongeldige Event Template Name value (%s). Het van toepassing zijnde Event template moet aangemaakt zijn voorafgaand aan de import.'
  },
  'import line parse error' => {
    'lastUpdated' => '1215443865',
    'message' => 'Er is een fout opgetreden bij het verwerken van deze invoer, \'%s\', op regel %d.'
  },
  'import missing required' => {
    'lastUpdated' => '1190026274',
    'message' => 'Record %d had geen ingevuld %s. Dit is een verplicht veld.'
  },
  'import need dup key' => {
    'lastUpdated' => '1190026246',
    'message' => 'Er moet ten minste een dubbele sleutel checkbox aangevinkt zijn.'
  },
  'import ok' => {
    'lastUpdated' => '1190026211',
    'message' => 'Alle %d records werden succesvol verwerkt. %d aangemaakt, %d witregels, %d dubbelingen %s.'
  },
  'import other line' => {
    'lastUpdated' => '1190026173',
    'message' => 'Record %d was %s.'
  },
  'import record parse error' => {
    'lastUpdated' => '1208521825',
    'message' => 'Er is een fout opgetreden bij het verwerken van record %d: \'%s\''
  },
  'importTicketsUrl' => {
    'lastUpdated' => '1216649217',
    'message' => 'Het URL voor het importeren van kaartjes. Momenteel is dit nog niet ge&iuml;mplementeerd.'
  },
  'inheritUrlFromParent' => {
    'lastUpdated' => '1257329584',
    'message' => 'Of de URL van de ouder overgenomen moet worden.'
  },
  'is required' => {
    'lastUpdated' => '1213703142',
    'message' => '%s is vereist.'
  },
  'isAdvSearch' => {
    'lastUpdated' => '1149861289',
    'message' => '<p>Een functie die aangeeft of een geavanceerd zoekformulier is opgevraagd. </p>'
  },
  'isExportable' => {
    'lastUpdated' => '1257329601',
    'message' => 'Of dit ticket wel of niet exporteerbaar is.'
  },
  'isHidden' => {
    'lastUpdated' => '1257329629',
    'message' => 'Of dit ticket voor het menu verborgen moet worden of niet.'
  },
  'isPackage' => {
    'lastUpdated' => '1257329648',
    'message' => 'Of dit ticket een pakket is of niet.'
  },
  'isPrototype' => {
    'lastUpdated' => '1257329663',
    'message' => 'Of dit ticket een prototype is of niet.'
  },
  'isRegistrationStaff' => {
    'lastUpdated' => '1216646415',
    'message' => 'Een voorwaardelijke variabele die waar is als de huidige gebruiker in de groep voor de organisatie van dit evenement zit.'
  },
  'item expiration time' => {
    'lastUpdated' => '1215443699',
    'message' => 'Verlooptijd object'
  },
  'item expiration time help' => {
    'lastUpdated' => '1215443801',
    'message' => 'Hoe lang moeten objecten in een winkelwagen bewaart worden voordat ze verlopen zijn en vrijgegeven worden, zodat iemand anders ze aan kan schaffen?'
  },
  'label' => {
    'lastUpdated' => '1213703170',
    'message' => 'Label'
  },
  'label help' => {
    'lastUpdated' => '1215443733',
    'message' => 'Het label voor het veld dat aan de gebruiker aangeeft waar het veld voor is.'
  },
  'last name' => {
    'lastUpdated' => '1148304378',
    'message' => 'Achternaam'
  },
  'lastModified' => {
    'lastUpdated' => '1257329685',
    'message' => 'Epoch datum waarop dit ticket voor het laatst is aangepast.'
  },
  'location' => {
    'lastUpdated' => '1213703469',
    'message' => 'Locatie'
  },
  'location help' => {
    'lastUpdated' => '1215428087',
    'message' => 'In welke kamer of op welke locatie is dit evenement?'
  },
  'lookup badge' => {
    'lastUpdated' => '1215428103',
    'message' => 'Zoek een naamplaatje op'
  },
  'lookup registrant template' => {
    'lastUpdated' => '1215428128',
    'message' => 'Opzoeken registrant sjabloon'
  },
  'lookup registrant template help' => {
    'lastUpdated' => '1215428172',
    'message' => 'Welk sjabloon moet gebruikt worden voor het opzoeken van registranten scherm?'
  },
  'lookupRegistrantTemplateId help' => {
    'lastUpdated' => '1216649302',
    'message' => 'Het ID van het sjabloonvoor het scherm waar registranten opgezocht kunnen worden.'
  },
  'lookupRegistrantUrl' => {
    'lastUpdated' => '1216649363',
    'message' => 'URL voor het verkrijgen van informatie over de naamplatjes van de huidige gebruiker, of voor alle gebruikers als de huidige gebruiker bij de organisatie hoort.'
  },
  'main template' => {
    'lastUpdated' => '1215428189',
    'message' => 'Hoofd sjabloon'
  },
  'main template help' => {
    'lastUpdated' => '1215428242',
    'message' => 'Welk sjabloon moet gebruikt worden voor het hoofdscherm waar een lijst met naamplaatjes staat die aangeschaft kunnen worden?'
  },
  'main template help body' => {
    'lastUpdated' => '1216649428',
    'message' => 'Dit sjabloon gebruikt YUI voor het weergeven van de meeste dingen. Pas de CSS aan voor het veranderen van het sjabloon of de stijl.'
  },
  'main template help title' => {
    'lastUpdated' => '1216649450',
    'message' => 'Evenementenbeheersysteem hoofdscherm sjabloon'
  },
  'manage' => {
    'lastUpdated' => '1213703477',
    'message' => 'Beheren'
  },
  'manage discount passes' => {
    'lastUpdated' => '1148304707',
    'message' => 'Beheer kortingspassen'
  },
  'manage event metadata' => {
    'lastUpdated' => '1215428263',
    'message' => 'Beheer metadata van evenement'
  },
  'manage events' => {
    'lastUpdated' => '1148304745',
    'message' => 'Beheer evenementen'
  },
  'manage prerequisite sets' => {
    'lastUpdated' => '1148304768',
    'message' => 'Beheer set met vereisten'
  },
  'manage prerequisites' => {
    'lastUpdated' => '1148304795',
    'message' => 'Beheer vereisten voor dit evenement'
  },
  'manage purchases' => {
    'lastUpdated' => '1148304821',
    'message' => 'Beheer verkopen'
  },
  'manage purchases template help title' => {
    'lastUpdated' => '1148306531',
    'message' => 'Beheer het aankoop sjabloon van het evenementen beheersysteem. '
  },
  'manage registrants' => {
    'lastUpdated' => '1148306547',
    'message' => 'Beheer deelnemers'
  },
  'manageBadgeGroupsUrl' => {
    'lastUpdated' => '1216649474',
    'message' => 'URL voor het tonen van een lijst van naamplaatjes groepen.'
  },
  'manageEventMetaFieldsUrl' => {
    'lastUpdated' => '1216649508',
    'message' => 'Het URL van het Beheer evenement metadata scherm.'
  },
  'manageEvents.label' => {
    'lastUpdated' => '1166194577',
    'message' => 'Een standaard tekst voor de link naar "Evenementen beheer".'
  },
  'manageEvents.url' => {
    'lastUpdated' => '1149861698',
    'message' => '<p>Een URL dat de gebruiker meeneemt naar het scherm waar evenementen beheerd kunnen worden (bijv.: toegevoegd, goedgekeurd, verwijderd). </p>'
  },
  'managePrereqsMessage' => {
    'lastUpdated' => '1148306675',
    'message' => 'Het formulier hieronder kan gebruikt worden voor het toevoegen van vereiste taken aan %s. '
  },
  'managePurchases.label' => {
    'lastUpdated' => '1166194601',
    'message' => 'De standaard tekst voor de link naar "Aankopen beheer".'
  },
  'managePurchases.url' => {
    'lastUpdated' => '1149861764',
    'message' => '<p>Een URL dat de gebruiker meeneemt naar het scherm waar aankopen beheerd kunnen worden (bijv.: toegevoegd, goedgekeurd, verwijderd). </p>'
  },
  'managePurchasesTitle' => {
    'lastUpdated' => '1149861029',
    'message' => '<p>Een internationaal label waarmee dit scherm wordt aangeduid. </p>'
  },
  'manageToolbar' => {
    'lastUpdated' => '1208521875',
    'message' => '<div class="&quot;&quot;helpIndent&quot;&quot;"><p>Een code voor een taakbalk met iconen voor verwijderen, bewerken en herrangschikken van evenementen. </p></div>'
  },
  'mark as checked in' => {
    'lastUpdated' => '1215428279',
    'message' => 'Markeer als ingechecked'
  },
  'mark as not checked in' => {
    'lastUpdated' => '1215428295',
    'message' => 'Markeer als niet ingechecked'
  },
  'maximumAttendees' => {
    'lastUpdated' => '1149860007',
    'message' => '<p>Het aantal mensen dat zich in mag schrijven voor dit evenement. </p>'
  },
  'menuTitle' => {
    'lastUpdated' => '1257329733',
    'message' => 'De titel van dit ticket, zoals het getoond moet worden in het menu.'
  },
  'message' => {
    'lastUpdated' => '1149861921',
    'message' => '<p>Dit zijn berichten van het systeem over het aantal en het soort resultaten dat getoond wordt. </p>'
  },
  'meta field help text' => {
    'lastUpdated' => '1258550041',
    'message' => 'Help tekst'
  },
  'meta field help text description' => {
    'lastUpdated' => '1258550103',
    'message' => 'Deze help tekst wordt getoond in de interface voor het toevoegen van evenementen.'
  },
  'meta fields' => {
    'lastUpdated' => '1215428308',
    'message' => 'Meta velden'
  },
  'meta hover help' => {
    'lastUpdated' => '1190026129',
    'message' => 'Dit veld is maatwerk. Vraag een beheerder om hulp.'
  },
  'missing prerequisites message' => {
    'lastUpdated' => '1208522006',
    'message' => 'Enkele van de geselecteerde evenementen vereisen de deelname aan een ander evenement. Zorg ervoor dat aan de lijst van vereisten hieronder is voldaan. '
  },
  'my submissions' => {
    'lastUpdated' => '1258549718',
    'message' => 'Mijn inschrijvingen'
  },
  'name' => {
    'lastUpdated' => '1216587185',
    'message' => 'De naam van de gebruiker met het naamplaatje'
  },
  'name.label' => {
    'lastUpdated' => '1149862027',
    'message' => '<p>Het label &quot;Evenement&quot;. </p>'
  },
  'new form' => {
    'lastUpdated' => '1258549768',
    'message' => 'Nieuw formulier'
  },
  'new price' => {
    'lastUpdated' => '1148307058',
    'message' => 'Nieuwe prijs'
  },
  'new submission' => {
    'lastUpdated' => '1258549735',
    'message' => 'Voeg een evenement toe'
  },
  'new submission form' => {
    'lastUpdated' => '1258549756',
    'message' => 'Beheer evenementen toevoegen'
  },
  'newWindow' => {
    'lastUpdated' => '1257329797',
    'message' => 'Of dit ticket in een nieuw window getoond moet worden.'
  },
  'next submission id label' => {
    'lastUpdated' => '1258549800',
    'message' => 'Id volgende toevoeging'
  },
  'next submission id label help' => {
    'lastUpdated' => '1258549840',
    'message' => 'Dit is de waarde voor het invullen van de eerste toevoeging, bewerk dit niet.'
  },
  'no' => {
    'lastUpdated' => '1190026100',
    'message' => 'nee'
  },
  'no import took place' => {
    'lastUpdated' => '1190026091',
    'message' => 'Er werden geen records geimporteerd. Er waren fouten in de input:'
  },
  'no more available' => {
    'lastUpdated' => '1224075669',
    'message' => 'Fout: Er zijn geen objecten meer voor verkoop beschikbaar.'
  },
  'no sets to display' => {
    'lastUpdated' => '1148307174',
    'message' => 'Er is geen enkele set van vereisten die getoond kan worden. '
  },
  'noSearchDialog' => {
    'lastUpdated' => '1149861816',
    'message' => '<p>Een functie die aangeeft of de gebruiker gevraagd heeft of er geen zoekfunctie getoond wordt, omdat deze verborgen moet worden. </p>'
  },
  'not checked in' => {
    'lastUpdated' => '1215428316',
    'message' => 'Niet ingechecked'
  },
  'notes' => {
    'lastUpdated' => '1213703487',
    'message' => 'Aantekeningen'
  },
  'null field error' => {
    'lastUpdated' => '1148307195',
    'message' => 'Het %s veld mag niet leeg zijn.'
  },
  'null field error recnum' => {
    'lastUpdated' => '1190026065',
    'message' => 'Het %s veld kan niet leeggelaten worden (entry %d).'
  },
  'numberOfSearchResults' => {
    'lastUpdated' => '1149861941',
    'message' => '<p>Het aantal gevonden resultaten. </p>'
  },
  'numberRegistered' => {
    'lastUpdated' => '1149859974',
    'message' => '<p>Het aantal mensen dat momenteel geregistreerd is voor dit evenement. </p>'
  },
  'operator type' => {
    'lastUpdated' => '1148307215',
    'message' => 'Type operator'
  },
  'operator type description' => {
    'lastUpdated' => '1208522022',
    'message' => 'Zijn alle of enkele van de hieronder geselecteerde evenementen vereist?'
  },
  'option to narrow' => {
    'lastUpdated' => '1148893693',
    'message' => 'De getoonde lijst met vereisten kan beperkt worden met gebruik van de standaard of geavanceerde filter opties hierboven.'
  },
  'organization' => {
    'lastUpdated' => '1215428327',
    'message' => 'Organisatie'
  },
  'otherBadgesInCart' => {
    'lastUpdated' => '1216646458',
    'message' => 'Een functie die links en labels bevat voor andere naamplaatjes in de winkelwagen van deze gebruiker.'
  },
  'overwrite' => {
    'lastUpdated' => '1190026038',
    'message' => 'overschrijven'
  },
  'overwritten' => {
    'lastUpdated' => '1190026021',
    'message' => 'overschreven'
  },
  'ownerUserId' => {
    'lastUpdated' => '1257329815',
    'message' => 'User id van de eigenaar van dit ticket.'
  },
  'paginateBar' => {
    'lastUpdated' => '1149861646',
    'message' => '<p>Een balk waarmee de gebruiker door de evenementen kan bladeren als er verschillende pagina&#39;s met evenementen zijn. </p>'
  },
  'pass name' => {
    'lastUpdated' => '1148307603',
    'message' => 'Naam kortingspas'
  },
  'pass name description' => {
    'lastUpdated' => '1148307741',
    'message' => 'De naam van de kortingspas. In het systeem wordt dit gebruikt voor referentie naar deze pas en de bijbehorende kortingen, dus kies een omschrijvende naam. Dit veld kan niet leeggelaten worden.'
  },
  'pending' => {
    'lastUpdated' => '1258549432',
    'message' => 'Wachtend'
  },
  'percent off' => {
    'lastUpdated' => '1148307566',
    'message' => 'Percentage'
  },
  'percentage discount' => {
    'lastUpdated' => '1215428355',
    'message' => 'Kortingspercentage'
  },
  'percentage discount help' => {
    'lastUpdated' => '1215442008',
    'message' => 'Welk kortingspercentage wordt toegepast op de kaarten als de gebruiker deze kortingspas aanschaft?'
  },
  'phone number' => {
    'lastUpdated' => '1148307551',
    'message' => 'Telefoonnummer'
  },
  'phoneNumber' => {
    'lastUpdated' => '1216587212',
    'message' => 'Het telefoonnummer van de eigenaar van het naamplaatje.'
  },
  'populate from address book' => {
    'lastUpdated' => '1215442136',
    'message' => 'Vullen met gegevens uit adresboek'
  },
  'pre registration price' => {
    'lastUpdated' => '1222939489',
    'message' => 'Voortijdige registratie prijs'
  },
  'pre registration price end date' => {
    'lastUpdated' => '1222939512',
    'message' => 'Einddatum voortijdige registratie prijs'
  },
  'pre registration price end date help' => {
    'lastUpdated' => '1222939464',
    'message' => 'De datum waarop de voortijdige registratie wordt vervangen door de vroege vogel prijs.'
  },
  'pre registration price help' => {
    'lastUpdated' => '1222939402',
    'message' => 'De speciale prijs van dit naamplaatje als de gebruiker zich absurd vroeg inschrijft.'
  },
  'prereq set name field description' => {
    'lastUpdated' => '1148893624',
    'message' => 'Een omschrijvende naam voor deze set met vereisten'
  },
  'prereq set name field label' => {
    'lastUpdated' => '1148893757',
    'message' => 'De naam van de set van vereisten'
  },
  'price' => {
    'lastUpdated' => '1222876008',
    'message' => 'Totale prijs'
  },
  'price help' => {
    'lastUpdated' => '1222876029',
    'message' => 'De normale prijs van dit naamkaartje'
  },
  'price must be greater than zero' => {
    'lastUpdated' => '1215443263',
    'message' => 'De prijs moet groeter zijn dan nul.'
  },
  'price.label' => {
    'lastUpdated' => '1149862092',
    'message' => '<p>Het label &quot;Prijs&quot;. </p>'
  },
  'print' => {
    'lastUpdated' => '1213703500',
    'message' => 'Afdrukken'
  },
  'print badge template' => {
    'lastUpdated' => '1215443316',
    'message' => 'Sjabloon afdrukken naamplaatje'
  },
  'print badge template help' => {
    'lastUpdated' => '1215443344',
    'message' => 'Welk sjabloon moet gebruikt worden voor het afdrukken van naamplaatjes?'
  },
  'print remaining ticket template' => {
    'lastUpdated' => '1257329860',
    'message' => 'Print overgebleven tickets sjabloon.'
  },
  'print remaining ticket template help' => {
    'lastUpdated' => '1257329898',
    'message' => 'Evenementenbeheersysteem Print overblijvende tickets sjabloon.'
  },
  'print remaining tickets' => {
    'lastUpdated' => '1257329913',
    'message' => 'Print overgebleven tickets.'
  },
  'print ticket template' => {
    'lastUpdated' => '1215443362',
    'message' => 'Sjabloon afdrukken kaartjes'
  },
  'print ticket template help' => {
    'lastUpdated' => '1215443388',
    'message' => 'Welk sjabloon moet gebruikt worden voor het afdrukken van kaarttjes?'
  },
  'printBadgeTemplateId help' => {
    'lastUpdated' => '1216649541',
    'message' => 'Het ID van het sjabloon waarmee een naamplaatje afgedrukt wordt.'
  },
  'printRemainingTicketsUrl' => {
    'lastUpdated' => '1257329934',
    'message' => 'URL naar de overgebleven tickets pagina.'
  },
  'printTicketTemplateId help' => {
    'lastUpdated' => '1216649565',
    'message' => 'Het ID van het sjabloon waarmee een kaartje afgedrukt wordt.<br /> '
  },
  'productId' => {
    'lastUpdated' => '1149861569',
    'message' => '<div class="&quot;helpIndent&quot;"><p>De unieke identificatie van dit product. </p></div>'
  },
  'purchase.label' => {
    'lastUpdated' => '1149860695',
    'message' => '<p>Het label &quot;Voeg toe aan winkelwagen&quot;. Deze variabele zal leeg zijn als het evenement is volgeboekt.</p>'
  },
  'purchase.message' => {
    'lastUpdated' => '1149860757',
    'message' => '<p>Dit is een bericht aan de gebruiker waarin gevraagd wordt of ze de sub-evenementen willen bekijken. Deze variabele zal leeg zijn als het evenement is volgeboekt.</p>'
  },
  'purchase.url' => {
    'lastUpdated' => '1149860726',
    'message' => '<p>Het URL waar de gebruiker zich in kan schrijven voor dit evenement en het toe kan voegen aan hun winkelwagen. Het URL zal leeg zijn als het evenement volgeboekt is.</p>'
  },
  'purchase.wantToContinue.url' => {
    'lastUpdated' => '1149860821',
    'message' => '<p>Het URL waar dit evenement aan de winkelwagen wordt toegevoegd. Deze variabele zal leeg zijn als het evenement is volgeboekt. </p>  '
  },
  'purchase.wantToSearch.url' => {
    'lastUpdated' => '1149860786',
    'message' => '<p>Het URL waar gezocht wordt naar evenementen die vereist zijn voor dit evenement. Deze variabele zal leeg zijn als het evenement is volgeboekt.</p>'
  },
  'purchaseComplete' => {
    'lastUpdated' => '1216647033',
    'message' => 'Een functie die waar is als de aanschaf van het naamplaatje voltooid is.'
  },
  'purchaseUrl' => {
    'lastUpdated' => '1149860961',
    'message' => '<div class="&quot;helpIndent&quot;"><p>Een link waar de details van de aankopen bekeken kunnen worden.</p></div>'
  },
  'purchasesLoop' => {
    'lastUpdated' => '1149860927',
    'message' => '<p>Deze kring bevat alle goedgekeurde evenementen, zodat gebruikers hun aankopen kunnen bekijken.</p>'
  },
  'quantity available' => {
    'lastUpdated' => '1215442156',
    'message' => '# Beschikbaar'
  },
  'refresh events list' => {
    'lastUpdated' => '1148893935',
    'message' => 'Vernieuw evenementen lijst.'
  },
  'refund' => {
    'lastUpdated' => '1215442855',
    'message' => 'Terugstorting'
  },
  'regLoop' => {
    'lastUpdated' => '1149862748',
    'message' => 'Deze kring bevat alle evenementen die bij deze registratie inbegrepen zijn.'
  },
  'registration info message' => {
    'lastUpdated' => '1208522173',
    'message' => '<p>Voer badge/contact informatie is voor de evenementen die momenteel toegevoegd worden aan de winkelwagen.</p><p>&nbsp;</p><p>Het gebruikers profiel kan na inloggen vernieuwd worden met deze informatie door uw naam te kiezen uit de dropdown-box of door de optie &quot;Maak een badge aan voor mijzelf.&quot; te kiezen als uw naam er niet tussen staat.</p><p>&nbsp;</p><p>Als een aankoop voor iemand anders wordt gedaan, selecteer dan de gewenste naam of de &quot;Maak een badge aan voor iemand anders.&quot; optie uit het menu. Wanneer objecten toegevoegd worden aan eerdere aankopen, is die badge nog geselecteerd en kan niet gewijzigd worden. Als in dit formulier velden worden aangepast terwijl een bestaande badge is geselecteerd, zal de informatie voor de badge vernieuwd worden. </p>'
  },
  'registration staff group' => {
    'lastUpdated' => '1216649578',
    'message' => 'Organisatie groep'
  },
  'registration staff group help' => {
    'lastUpdated' => '1216649630',
    'message' => 'Kies een groep gebruikers die de registraties afhandelen. Deze gebruikers kunnen naamplaatje registraties opzoeken en beheren voor alle ingeschreven gebruikers.'
  },
  'registrationId' => {
    'lastUpdated' => '1166194634',
    'message' => 'De registratie identificatie van deze gebruiker voor dit evenement.'
  },
  'registrationStaffGroupId help' => {
    'lastUpdated' => '1216649652',
    'message' => 'Het ID van de groep die registraties behandeld.'
  },
  'related badge groups' => {
    'lastUpdated' => '1215443451',
    'message' => 'Verwante groepen naamplaatjes'
  },
  'related badge groups badge help' => {
    'lastUpdated' => '1215443578',
    'message' => 'Ga de groepen naamplaatjes na die aan dit naamplaatje gerelateerd zijn, zodat vereiste naamplaatjes aan kaartjes kunnen worden toegewezen.'
  },
  'related badge groups ticket help' => {
    'lastUpdated' => '1215443664',
    'message' => 'Geef de groepen naamplaatjes aan die als vereiste kunnen worden opgegeven voor deelname aan het evenement. Als er geen geselecteerd wordt, is elk naamplaatje afdoende.'
  },
  'related ribbons' => {
    'lastUpdated' => '1215443463',
    'message' => 'Verwante kortingspassen'
  },
  'related ribbons help' => {
    'lastUpdated' => '1215443497',
    'message' => 'Ga de kortingspassen na die een korting geven op dit kaartje.'
  },
  'relatedBadgeGroups' => {
    'lastUpdated' => '1257330475',
    'message' => 'Groepen voor naamkaartjes met relatie tot dit ticket.'
  },
  'relatedRibbons' => {
    'lastUpdated' => '1257330515',
    'message' => 'Koringspassen gerelateerd aan dit ticket.'
  },
  'remove' => {
    'lastUpdated' => '1215443221',
    'message' => 'Verwijderen'
  },
  'reset user' => {
    'lastUpdated' => '1148309951',
    'message' => 'Ken beginwaarden toe aan gebruiker'
  },
  'returned' => {
    'lastUpdated' => '1149862825',
    'message' => 'Een functie die 1 is als dit evenement is teruggestuurd door de gebruiker.'
  },
  'revisedBy' => {
    'lastUpdated' => '1257330533',
    'message' => 'Id van de gebruiker die dit ticket het laatst heeft aangepast.'
  },
  'revisionDate' => {
    'lastUpdated' => '1257330552',
    'message' => 'De epoch datum waarop de ticket het laatst is aangepast.'
  },
  'ribbon instructions' => {
    'lastUpdated' => '1215442939',
    'message' => 'Instructies kortingspas'
  },
  'ribbon instructions help' => {
    'lastUpdated' => '1215442960',
    'message' => 'Geef de gebruiker hulp bij het gebruik van een kortingspas.'
  },
  'ribbonInstructions help' => {
    'lastUpdated' => '1216646924',
    'message' => 'Gebruikersinstructies voor de kortingspas'
  },
  'ribbons' => {
    'lastUpdated' => '1215442841',
    'message' => 'Kortingspassen'
  },
  'schedule back link' => {
    'lastUpdated' => '1246969520',
    'message' => 'Terug'
  },
  'schedule number of columns' => {
    'lastUpdated' => '1246969546',
    'message' => 'Aantal locaties per pagina'
  },
  'schedule number of columns help' => {
    'lastUpdated' => '1246969672',
    'message' => 'Dit bepaalt hoeveel locaties voor evenementen per pagina getoond worden in de planner. Als het evenement slechts enkele locaties zal beslaan, zet het op dat aantal. Voor 10 tot 20 locaties wordt eenderde tot de helft van het aantal aanbevolen en voor meer de standaardwaarde.'
  },
  'schedule template' => {
    'lastUpdated' => '1246969687',
    'message' => 'Planner sjabloon'
  },
  'schedule template help' => {
    'lastUpdated' => '1246969733',
    'message' => 'Dit sjabloon wordt gebruikt voor het tonen van de planning van evenementen.'
  },
  'scheduling conflict continue' => {
    'lastUpdated' => '1148894598',
    'message' => 'Klik hier om verder te gaan.'
  },
  'scheduling conflict message' => {
    'lastUpdated' => '1148313739',
    'message' => 'U heeft een conflict in het programma. Verwijder alstublieft &eacute;&eacute;n van de evenementen uit de winkelwagen hieronder om zodoende het probleem op te lossen.'
  },
  'search' => {
    'lastUpdated' => '1213703507',
    'message' => 'Zoeken'
  },
  'search template help title' => {
    'lastUpdated' => '1148309979',
    'message' => 'Zoek sjabloon voor het evenementen beheersysteem'
  },
  'search.data.url' => {
    'lastUpdated' => '1149862180',
    'message' => '<p>De URL naar deze asset. </p>'
  },
  'search.filters.options' => {
    'lastUpdated' => '1149862154',
    'message' => '<p>Een Javascript voor een zoekmachine voor evenementen, gebaseerd op hun eigenschappen en metadata. </p>'
  },
  'search.formFooter' => {
    'lastUpdated' => '1149861308',
    'message' => '<p>Code voor voetnoot voor beide typen zoekopdrachten. </p>'
  },
  'search.formSubmit' => {
    'lastUpdated' => '1149861326',
    'message' => '<p>Een knop waarmee de zoek data van de gebruiker ingevoerd wordt. De knop zal het internationale woord Filter bevatten. </p>'
  },
  'seats available' => {
    'lastUpdated' => '1148307662',
    'message' => 'Aantal beschikbare plaatsen'
  },
  'seats available help' => {
    'lastUpdated' => '1215442194',
    'message' => 'Hoeveel mensen kunnen dit object aanschaffen voordat de ruimte op is?'
  },
  'seats.label' => {
    'lastUpdated' => '1149862114',
    'message' => '<p>Het label &quot;Plaatsen&quot;. </p>'
  },
  'seatsAvailable' => {
    'lastUpdated' => '1257330569',
    'message' => 'Totaal aantal stoelen dat beschikbaar is voor dit ticket.'
  },
  'seatsRemaining' => {
    'lastUpdated' => '1149860043',
    'message' => '<p>Het aantal plaatsen dat nog beschikbaar is. </p>'
  },
  'see available subevents' => {
    'lastUpdated' => '1148308134',
    'message' => 'Wilt u de beschikbare sub-evenementen zien?'
  },
  'select form to edit' => {
    'lastUpdated' => '1258549856',
    'message' => 'Selecteer een formulier voor het bewerken'
  },
  'select form to submit' => {
    'lastUpdated' => '1258549874',
    'message' => 'Selecteer een formulier om een evenement toe te voegen'
  },
  'select one' => {
    'lastUpdated' => '1148308110',
    'message' => 'Selecteer &eacute;&eacute;n'
  },
  'select one or more' => {
    'lastUpdated' => '1148308082',
    'message' => 'Selecteer &eacute;&eacute;n of meer'
  },
  'short title' => {
    'lastUpdated' => '1190026010',
    'message' => 'titel'
  },
  'skip' => {
    'lastUpdated' => '1190026000',
    'message' => 'overslaan'
  },
  'skipNotification' => {
    'lastUpdated' => '1257330594',
    'message' => 'Of notificaties voor dit ticket overgeslagen moeten worden of niet.'
  },
  'skipped' => {
    'lastUpdated' => '1190025991',
    'message' => 'overgeslagen'
  },
  'sku' => {
    'lastUpdated' => '1148307639',
    'message' => 'SKU'
  },
  'sku description' => {
    'lastUpdated' => '1148307938',
    'message' => 'Een SKU nummer dat toegekend wordt aan het evenement. Een algemene unieke identificatie wordt standaard gegenereerd. '
  },
  'sku template' => {
    'lastUpdated' => '1148307849',
    'message' => 'SKU sjabloon'
  },
  'sku template description' => {
    'lastUpdated' => '1208522249',
    'message' => 'Dit veld bepaalt hoe de SKU voor elke product categorie wordt samengesteld. De syntax is hetzelfde als die van normale sjablonen.'
  },
  'sold out' => {
    'lastUpdated' => '1148307782',
    'message' => 'Uitverkocht'
  },
  'startDate' => {
    'lastUpdated' => '1149861493',
    'message' => '<div class="&quot;helpIndent&quot;"><p>De datum en tijd waarop dit evenement begint, in epoch formaat. </p></div>'
  },
  'startDate.human' => {
    'lastUpdated' => '1149860425',
    'message' => '<p>De begindatum-en tijd van dit evenement, in een door mensen te lezen formaat.</p>'
  },
  'startDateHuman' => {
    'lastUpdated' => '1149860439',
    'message' => '<p>De begindatum-en tijd van dit evenement, in een door mensen te lezen formaat.</p>'
  },
  'starts' => {
    'lastUpdated' => '1148307756',
    'message' => 'Begint'
  },
  'starts.label' => {
    'lastUpdated' => '1149862053',
    'message' => '<p>Het label &quot;Begint&quot;.</p>'
  },
  'state' => {
    'lastUpdated' => '1148307829',
    'message' => 'Provincie'
  },
  'status' => {
    'lastUpdated' => '1215442215',
    'message' => 'Status'
  },
  'submission queue' => {
    'lastUpdated' => '1258549888',
    'message' => 'Wachtrij toevoegingen'
  },
  'submitted location list help' => {
    'lastUpdated' => '1258549972',
    'message' => 'Voer een lijst met loacties in, 1 per regel. Deze lijst is beschikbaar in het formulier voor het toevoegen van evenmenten. Als dit veld ingevuld is zijn alleen deze loacties beschikbaar.'
  },
  'submitted location list label' => {
    'lastUpdated' => '1258549995',
    'message' => 'Beschikbare locaties voor toevoegen evenementen'
  },
  'switch to badge for' => {
    'lastUpdated' => '1215442625',
    'message' => 'Verander naar \'%s\' naamplaatje'
  },
  'synopsis' => {
    'lastUpdated' => '1257330644',
    'message' => 'Samenvatting van de beschrijving van dit ticket.'
  },
  'tagId' => {
    'lastUpdated' => '1257330667',
    'message' => 'Tag id van dit ticket'
  },
  'template help title' => {
    'lastUpdated' => '1148307959',
    'message' => 'Evenementen beheersysteem sjabloon'
  },
  'templateId' => {
    'lastUpdated' => '1149862868',
    'message' => 'Het gebruikte sjabloon voor het weergeven van dit evenement als dit opgevraagd wordt.'
  },
  'templateId help' => {
    'lastUpdated' => '1216646966',
    'message' => 'De ID van het sjabloon dat voor het hoofdscherm van het evenementenbeheersysteem gebruikt wordt.'
  },
  'ticket instructions' => {
    'lastUpdated' => '1215442671',
    'message' => 'Instructies bij kaarten'
  },
  'ticket instructions help' => {
    'lastUpdated' => '1215442694',
    'message' => 'Geef de gebruiker hulp bij het gebruik van kaartjes'
  },
  'ticketDuration' => {
    'lastUpdated' => '1216986300',
    'message' => 'Hoe lang het kaartje geldig is.'
  },
  'ticketEventNumber' => {
    'lastUpdated' => '1216986316',
    'message' => 'Het evenement nummer van het kaartje.'
  },
  'ticketInstructions help' => {
    'lastUpdated' => '1216646994',
    'message' => 'Gebruikersinstructies voor kaartjes.'
  },
  'ticketLocation' => {
    'lastUpdated' => '1216986330',
    'message' => 'Waar het kaartje toegang toe geeft.'
  },
  'ticketMeta_[LABEL]' => {
    'lastUpdated' => '1257330947',
    'message' => 'Waarde van het meta data veld [LABEL]. Niet-woord en spaties, tabs e.d. in [LABEL] moeten vervangen worden door een underscore ( _ ).

Voorveeld: Meta data label: naar "Telefoon thuis" moet als volgt naar gerefereerd worden: <tmpl_var ticketMeta_Telefoon_thuis>.'
  },
  'ticketStart' => {
    'lastUpdated' => '1216986344',
    'message' => 'De startdatum van het kaartje.'
  },
  'ticketTitle' => {
    'lastUpdated' => '1216986361',
    'message' => 'De titel van het af te drukken kaartje.'
  },
  'tickets' => {
    'lastUpdated' => '1213703516',
    'message' => 'Kaartjes'
  },
  'tickets_loop' => {
    'lastUpdated' => '1257330974',
    'message' => 'Een functie die alle overgebleven tickets en de bijbehorende data bevat.'
  },
  'time zone' => {
    'lastUpdated' => '1213703540',
    'message' => 'Tijdzone'
  },
  'time zone help' => {
    'lastUpdated' => '1215442725',
    'message' => 'Selecteer de tijdszone waarin dit evenement plaats zal vinden.'
  },
  'timezone help' => {
    'lastUpdated' => '1216646760',
    'message' => 'De tijdszone waarin dit evenement zal plaatsvinden volgens de configuratie.'
  },
  'title' => {
    'lastUpdated' => '1149859714',
    'message' => 'De titel van dit evenement'
  },
  'title.url' => {
    'lastUpdated' => '1166194684',
    'message' => 'Een URL waar een lijst met evenementen die dit evenement bevatten getoond wordt.'
  },
  'tmplLoop errorLoop' => {
    'lastUpdated' => '1189348509',
    'message' => 'In deze loop zijn foutmeldingen beschikbaar die samenhangen met het voltooien van de registratie van een deelnemer voor een conferentie. Deze loop bevat alleen foutmeldingen als "isError" waar is.'
  },
  'tmplVar approved' => {
    'lastUpdated' => '1149862933',
    'message' => 'Een functie die 1 is als het evenement is goedgekeurd.'
  },
  'tmplVar error' => {
    'lastUpdated' => '1189348581',
    'message' => 'Deze variabele bevat een foutmelding in de eigen taal van de gebruiker die aangeeft dat een bepaald veld niet leeg gelaten kan worden in het formulier. De veldnaam in de foutmelding is het label van de foutmelding in de eigen taal. '
  },
  'tmplVar event' => {
    'lastUpdated' => '1150097413',
    'message' => 'De informatie, die met haar eigen sjabloon bewerkt is, over een enkel evenement.'
  },
  'tmplVar isError' => {
    'lastUpdated' => '1207836110',
    'message' => 'Deze variabele wordt gebruikt binnen een tmpl_if statement en is waar als er een foutmelding is ontstaan tijdens de verwerking van de registratie van een deelnemer. Deze variabele is alleen waar als de &quot;registration&quot; template variabele waar is.'
  },
  'tmplVar price' => {
    'lastUpdated' => '1150097432',
    'message' => 'De prijs van dit evenement.'
  },
  'tmplVar sku' => {
    'lastUpdated' => '1150097943',
    'message' => 'De SKU van dit evenement.'
  },
  'tmplVar sku template' => {
    'lastUpdated' => '1150097992',
    'message' => 'De SKU sjablonen die gebruikt worden voor het genereren van de SKU van dit evenement.'
  },
  'tmplVar weight' => {
    'lastUpdated' => '1150098031',
    'message' => 'Het gewicht van de materialen die bij dit evenement gebruikt worden.'
  },
  'token instructions' => {
    'lastUpdated' => '1215446943',
    'message' => 'Instructies voucher'
  },
  'token instructions help' => {
    'lastUpdated' => '1216646489',
    'message' => 'Geef de gebruiker hulp bij het gebruik van een kortingspas.'
  },
  'tokenInstructions help' => {
    'lastUpdated' => '1216649683',
    'message' => 'Instructies voor de gebruiker voor het gebruik van een voucher.'
  },
  'tokens' => {
    'lastUpdated' => '1215446924',
    'message' => 'Vouchers'
  },
  'transactionId' => {
    'lastUpdated' => '1150098067',
    'message' => 'De unieke identificatie in de database van deze transactie. '
  },
  'transactionItemId' => {
    'lastUpdated' => '1216646701',
    'message' => 'De unieke identificatie van de transactie voor dit naamplaatje, voor interne doeleinden.'
  },
  'type label here' => {
    'lastUpdated' => '1148307486',
    'message' => 'Voer hier het label in'
  },
  'type name here' => {
    'lastUpdated' => '1148307472',
    'message' => 'Voer hier de naam in'
  },
  'url' => {
    'lastUpdated' => '1216646510',
    'message' => 'Het URL van dit evenementenbeheersysteem.'
  },
  'usePackedHeadTags' => {
    'lastUpdated' => '1257331006',
    'message' => 'Of samengestelde header tags gebruikt moeten worden voor dit ticket of niet.'
  },
  'user' => {
    'lastUpdated' => '1213703549',
    'message' => 'Gebruiker'
  },
  'userId' => {
    'lastUpdated' => '1150098144',
    'message' => 'De identificatie van de gebruiker die deze badge gaat gebruiken.'
  },
  'view badge template' => {
    'lastUpdated' => '1221207538',
    'message' => 'Evenementenbeheersysteem sjabloon voor naamplaatjes.<br />   '
  },
  'view badge template help' => {
    'lastUpdated' => '1221207576',
    'message' => 'Het sjabloon waarmee een formulier wordt getoond waar de gebruiker de informatie van het naamplaatje in kan voeren.'
  },
  'view badges' => {
    'lastUpdated' => '1215442830',
    'message' => 'Bekijk naamplaatjes'
  },
  'view my submissions' => {
    'lastUpdated' => '1258550010',
    'message' => 'Mijn toegevoegde evenementen'
  },
  'view purchase' => {
    'lastUpdated' => '1148307452',
    'message' => 'Bekijk aankoop'
  },
  'view purchase template help title' => {
    'lastUpdated' => '1148307405',
    'message' => 'Bekijk aankopen sjabloon van het evenementen beheersysteem'
  },
  'view schedule' => {
    'lastUpdated' => '1246969748',
    'message' => 'Planner'
  },
  'view submission queue' => {
    'lastUpdated' => '1258550027',
    'message' => 'Wachtrij evenement'
  },
  'view tickets' => {
    'lastUpdated' => '1213703530',
    'message' => 'Bekijk kaartjes'
  },
  'viewCartUrl' => {
    'lastUpdated' => '1216646650',
    'message' => 'Een URL dat de gebruiker naar de winkelwagen meeneemt.'
  },
  'viewEventsUrl' => {
    'lastUpdated' => '1216646619',
    'message' => 'URL waar kaartjes bekeken kunnen worden.'
  },
  'viewPurchaseTitle' => {
    'lastUpdated' => '1149862711',
    'message' => 'Een label voor de titel van dit scherm.'
  },
  'weight' => {
    'lastUpdated' => '1148307369',
    'message' => 'Gewicht'
  },
  'weight description' => {
    'lastUpdated' => '1148307358',
    'message' => 'Het gewicht van alles wat geassocieerd kan worden met uw evenement.'
  },
  'what about duplicates' => {
    'lastUpdated' => '1190025968',
    'message' => 'Wat doen we met dubbelingen?'
  },
  'which badge' => {
    'lastUpdated' => '1148307325',
    'message' => 'Welke badge'
  },
  'whichTab' => {
    'lastUpdated' => '1216646589',
    'message' => 'Het geselecteerde tabblad in het scherm waar de naamplaatjes gemaakt worden.'
  },
  'yes' => {
    'lastUpdated' => '1190025955',
    'message' => 'ja'
  },
  'you' => {
    'lastUpdated' => '1148307315',
    'message' => 'U'
  },
  'you do not have any metadata fields to display' => {
    'lastUpdated' => '1148307264',
    'message' => 'Er zijn geen metadata velden die getoond kunnen worden. '
  },
  'zip code' => {
    'lastUpdated' => '1148307237',
    'message' => 'Postcode'
  },
  'zipcode' => {
    'lastUpdated' => '1216646543',
    'message' => 'De postcode van de houder van het naamplaatje.'
  }
}
;

1;
